#ifndef R_NO_REMAP
#define R_NO_REMAP
#endif
#ifndef __RXTHREADDATA_H__
#define __RXTHREADDATA_H__

#if defined(__cplusplus)
extern "C" {
#endif

  void setIndPointersByThread(rx_solving_options_ind *ind);

#if defined(__cplusplus)
}
#endif

#endif // __RXTHREADDATA_H__
